function vo_drawordertrain(yorder,zorder,tl,fignum)
% VO_DRAWORDERTRAIN draws the (ky,kz) phase encodes
%    VO_DRAWORDERTRAIN(YORDER,ZORDER,TRAINL,[FIGNUM]) draws the
%    phase-encode ordering specified by vectors YORDER and ZORDER. An
%    optional (but recommended) figure number parameter, FIGNUM, can
%    be identified to draw the animation in a specific
%    figure. TRAINL specifies the length of each radial spoke. To
%    also see the ordering of each spoke, set TRAINL = 1.
%
% See also VO_VDRAD.
%   
% (c) Joseph Y Cheng (jycheng@mrsrl.stanford.edu) 2012
%

% SVN info: 
%   Date:     $Date: 2013-07-23 15:34:07 -0700 (Tue, 23 Jul 2013) $
%   Revision: $Revision: 1348 $
%   Author:   $Author: jycheng $
%   Id:       $Id: vo_drawordertrain.m 1348 2013-07-23 22:34:07Z jycheng $
   
    mode = 1; % If 1, draw as image. Otherwise, draw as plot
    
    %% if not specified, draw in current fig (not ideal)
    if nargin < 4
        fignum = gcf;
    end
    
    %% setup
    if mode == 1
        mask = zeros(max(yorder),max(zorder));
    else
        cmap = colormap('jet');
        cmapl = size(cmap,1);
    end
    sfigure(fignum); hold off;    

    for N=tl:tl:length(yorder)
        ind = (N-tl)+(1:tl);
        if mode == 1
            for I=ind
                mask(yorder(I),zorder(I)) = 1;
            end
            sfigure(fignum), imshow(mask,[]), drawnow;
        else
            sfigure(fignum);
            p = plot(yorder(ind),zorder(ind),'.k');
            cmapi = ceil(N/length(yorder)*cmapl);
            set(p,'Color',cmap(cmapi,:));
            drawnow;
            axis([min(yorder)-1 max(yorder)+1 min(zorder)-1 max(zorder)+1]);
            axis equal;
            hold on;
        end
    end

